"opt" <-
  function(...) {
    new("opt", ...)
  }
